enum TaskStatus {
Backlog,
NotYetTriaged,
InProgress,
Blocked,
}Expand description
The task’s status
Variants
Backlog
Not currently active, but planned for later, at some point
NotYetTriaged
Completely new on the list, needs triaging first
InProgress
Currently being worked on
Blocked
Used to be worked on, but currently blocked by something (reason goes into the description)